import { _decorator, sp, Component, Node, Quat, Color, color, tween } from 'cc';
const { ccclass, property, menu } = _decorator;


@ccclass
@menu("spineTest/spineTest")
export default class spineTest extends Component {
    @property({
        type: sp.Skeleton,
        displayName: "测试龙骨",
        tooltip: '测试龙骨',
    })
    m_pSpTestCpt: sp.Skeleton | null = null;

    @property({
        displayName: "测试旋转角度增益",
        tooltip: '测试旋转角度增益',
    })
    m_nRotationZAdd: number = 30;
    m_nRotationZOri: number = 0;

    @property({
        displayName: "测试渐变颜色缓动时间",
        tooltip: '测试渐变颜色缓动时间',
    })
    m_nTintRunTime: number = 0.5;

    @property({
        type: Color,
        displayName: "测试渐变颜色",
        tooltip: "测试渐变颜色",
    })
    m_clrTint: Color = color(255, 0, 0, 255);
    m_clrTintOri: Color = color(255, 255, 255, 255);

    // LIFE-CYCLE CALLBACKS:

    onLoad() {
        if(this.m_pSpTestCpt) {
            this.m_clrTintOri = this.m_pSpTestCpt.color.clone();
            this.m_nRotationZOri = this.m_pSpTestCpt.node.eulerAngles.z;
        }
    }

    onDestroy() {

    }

    onTestRotate() {
        if(!this.m_pSpTestCpt) {
            return;
        }
        if(this.m_nRotationZAdd == 0) {
            return;
        }
        let nAngleZ = this.m_pSpTestCpt.node.eulerAngles.z + this.m_nRotationZAdd;
        if(nAngleZ > 90) {
            nAngleZ -= 180;  //??
        }
        //this.m_pSpTestCpt.node.setRotationFromEuler(this.m_pSpTestCpt.node.eulerAngles.x,
        // this.m_pSpTestCpt.node.eulerAngles.y,
        // nAngleZ);
        let pQuat = new Quat();
        Quat.fromAngleZ(pQuat, nAngleZ);
        this.m_pSpTestCpt.node.setRotation(pQuat);
    }

    onTestTint() {
        if(!this.m_pSpTestCpt) {
            return;
        }
        if(this.m_nTintRunTime <= 0) {
            return;
        }
        this.m_pSpTestCpt.color = this.m_clrTint;
        tween(this.m_pSpTestCpt.color)
            .to(this.m_nTintRunTime, {r: this.m_clrTintOri.r, g: this.m_clrTintOri.g, b: this.m_clrTintOri.b})
            .start();
    }

    onTestReset() {
        if(!this.m_pSpTestCpt) {
            return;
        }
        this.m_pSpTestCpt.color = this.m_clrTintOri;
        //this.m_pSpTestCpt.node.setRotationFromEuler(this.m_pSpTestCpt.node.eulerAngles.x,
        // this.m_pSpTestCpt.node.eulerAngles.y,
        // this.m_nRotationZOri);
        let pQuat = new Quat();
        Quat.fromAngleZ(pQuat, this.m_nRotationZOri);
        this.m_pSpTestCpt.node.setRotation(pQuat);
    }

    // update (dt) {}
}
